@@ -17,19 +17,36 @@ limitations under the License.
 package services;
 
 import annotations.Area;
+import mixins.Follow;
 import org.ovirt.api.metamodel.annotations.In;
+import org.ovirt.api.metamodel.annotations.InputDetail;
 import org.ovirt.api.metamodel.annotations.Out;
 import org.ovirt.api.metamodel.annotations.Service;
 import types.CpuProfile;
 
+import static org.ovirt.api.metamodel.language.ApiLanguage.optional;
+
 @Service
 @Area("Virtualization")
 public interface CpuProfileService {
-    interface Get {
+    interface Get extends Follow {
         @Out CpuProfile profile();
     }
 
+    /**
+     * Update the specified cpu profile in the system.
+     *
+     * @author Ori Liel <oliel@redhat.com>
+     * @date 18 Jan 2017
+     * @status added
+     */
     interface Update {
+        @InputDetail
+        default void inputDetail() {
+            optional(profile().description());
+            optional(profile().name());
+            optional(profile().qos().id());
+        }
         @In @Out CpuProfile profile();
 
         /**
