@@ -17,11 +17,15 @@ limitations under the License.
 package services;
 
 import annotations.Area;
+import mixins.Follow;
 import org.ovirt.api.metamodel.annotations.In;
+import org.ovirt.api.metamodel.annotations.InputDetail;
 import org.ovirt.api.metamodel.annotations.Out;
 import org.ovirt.api.metamodel.annotations.Service;
 import types.DataCenter;
 
+import static org.ovirt.api.metamodel.language.ApiLanguage.mandatory;
+import static org.ovirt.api.metamodel.language.ApiLanguage.optional;
 /**
  * A service to manage data centers.
  *
@@ -59,6 +63,17 @@ public interface DataCentersService {
      * @status added
      */
     interface Add {
+        @InputDetail
+        default void inputDetail() {
+            mandatory(dataCenter().local());
+            mandatory(dataCenter().name());
+            optional(dataCenter().comment());
+            optional(dataCenter().description());
+            optional(dataCenter().macPool().id());
+            optional(dataCenter().storageFormat());
+            optional(dataCenter().version().major());
+            optional(dataCenter().version().minor());
+        }
         /**
          * The data center that is being added.
          *
@@ -135,7 +150,7 @@ public interface DataCentersService {
      * @date 14 Sep 2016
      * @status added
      */
-    interface List {
+    interface List extends Follow {
         @Out DataCenter[] dataCenters();
 
         /**
