@@ -17,15 +17,24 @@ limitations under the License.
 package services;
 
 import annotations.Area;
+import mixins.Follow;
 import org.ovirt.api.metamodel.annotations.In;
+import org.ovirt.api.metamodel.annotations.InputDetail;
 import org.ovirt.api.metamodel.annotations.Out;
 import org.ovirt.api.metamodel.annotations.Service;
 import types.Network;
 
+import static org.ovirt.api.metamodel.language.ApiLanguage.mandatory;
+import static org.ovirt.api.metamodel.language.ApiLanguage.or;
+
 @Service
 @Area("Network")
 public interface VirtualFunctionAllowedNetworksService {
     interface Add {
+        @InputDetail
+        default void inputDetail() {
+            or(mandatory(network().id()), mandatory(network().name()));
+        }
         @In @Out Network network();
     }
 
@@ -38,7 +47,7 @@ public interface VirtualFunctionAllowedNetworksService {
      * @date 15 Apr 2017
      * @status added
      */
-    interface List {
+    interface List extends Follow {
         @Out Network[] networks();
 
         /**
