@@ -281,6 +281,47 @@ public interface ClusterService extends Service {
      */
     GetRequest get();
     
+    /**
+     * Refresh the Gluster heal info for all volumes in cluster.
+     * 
+     * For example, Cluster `123`, send a request like
+     * this:
+     * 
+     * [source]
+     * ----
+     * POST /ovirt-engine/api/clusters/123/refreshglusterhealstatus
+     * ----
+     */
+    public interface RefreshGlusterHealStatusRequest extends Request<RefreshGlusterHealStatusRequest, RefreshGlusterHealStatusResponse> {
+    }
+    
+    /**
+     * Refresh the Gluster heal info for all volumes in cluster.
+     * 
+     * For example, Cluster `123`, send a request like
+     * this:
+     * 
+     * [source]
+     * ----
+     * POST /ovirt-engine/api/clusters/123/refreshglusterhealstatus
+     * ----
+     */
+    public interface RefreshGlusterHealStatusResponse extends Response {
+    }
+    
+    /**
+     * Refresh the Gluster heal info for all volumes in cluster.
+     * 
+     * For example, Cluster `123`, send a request like
+     * this:
+     * 
+     * [source]
+     * ----
+     * POST /ovirt-engine/api/clusters/123/refreshglusterhealstatus
+     * ----
+     */
+    RefreshGlusterHealStatusRequest refreshGlusterHealStatus();
+    
     /**
      * Removes the cluster from the system.
      * 
@@ -470,6 +511,81 @@ public interface ClusterService extends Service {
      */
     UpdateRequest update();
     
+    /**
+     * Start or finish upgrade process for the cluster based on the action value. This action marks the cluster for
+     * upgrade or clears the upgrade running flag on the cluster based on the action value which takes values of
+     * start or stop.
+     * 
+     * [source]
+     * ----
+     * POST /ovirt-engine/api/clusters/123/upgrade
+     * ----
+     * 
+     * With a request body like this to mark the cluster for upgrade:
+     * 
+     * [source,xml]
+     * ----
+     * <action>
+     *     <upgrade_action>
+     *         start
+     *     </upgrade_action>
+     * </action>
+     * ----
+     */
+    public interface UpgradeRequest extends Request<UpgradeRequest, UpgradeResponse> {
+        /**
+         * Indicates if the action should be performed asynchronously.
+         */
+        UpgradeRequest async(Boolean async);
+    }
+    
+    /**
+     * Start or finish upgrade process for the cluster based on the action value. This action marks the cluster for
+     * upgrade or clears the upgrade running flag on the cluster based on the action value which takes values of
+     * start or stop.
+     * 
+     * [source]
+     * ----
+     * POST /ovirt-engine/api/clusters/123/upgrade
+     * ----
+     * 
+     * With a request body like this to mark the cluster for upgrade:
+     * 
+     * [source,xml]
+     * ----
+     * <action>
+     *     <upgrade_action>
+     *         start
+     *     </upgrade_action>
+     * </action>
+     * ----
+     */
+    public interface UpgradeResponse extends Response {
+    }
+    
+    /**
+     * Start or finish upgrade process for the cluster based on the action value. This action marks the cluster for
+     * upgrade or clears the upgrade running flag on the cluster based on the action value which takes values of
+     * start or stop.
+     * 
+     * [source]
+     * ----
+     * POST /ovirt-engine/api/clusters/123/upgrade
+     * ----
+     * 
+     * With a request body like this to mark the cluster for upgrade:
+     * 
+     * [source,xml]
+     * ----
+     * <action>
+     *     <upgrade_action>
+     *         start
+     *     </upgrade_action>
+     * </action>
+     * ----
+     */
+    UpgradeRequest upgrade();
+    
     /**
      * A reference to the service that manages affinity groups.
      */
