@@ -15,29 +15,39 @@ limitations under the License.
 
 package org.ovirt.engine.sdk4.types;
 
-
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 public enum VmDeviceType {
+    CDROM("cdrom"),
+    FLOPPY("floppy"),
+    ;
     
-    FLOPPY,
-    CDROM;
+    private static final Logger log = LoggerFactory.getLogger(VmDeviceType.class);
     
-    private static final Logger LOG = LoggerFactory.getLogger(VmDeviceType.class);
+    private String image;
+    
+    VmDeviceType(String image) {
+        this.image = image;
+    }
     
     public String value() {
-        return name().toLowerCase();
+        return image;
     }
     
     public static VmDeviceType fromValue(String value) {
         try {
             return valueOf(value.toUpperCase());
         }
-        catch (IllegalArgumentException e) {
-            LOG.error("The string '" + value + "' isn't a valid value for the 'VmDeviceType' enumerated type. Valid values are: 'floppy', 'cdrom'.");
+        catch (IllegalArgumentException exception) {
+            log.error(
+            "The string '" + value + "' isn't a valid value for the 'VmDeviceType' enumerated type. " +
+            "Valid values are 'cdrom' and 'floppy'.",
+            exception
+            );
             return null;
         }
     }
     
 }
+
