@@ -210,6 +210,10 @@ public class Builders {
         return new EventBuilder();
     }
     
+    public static EventSubscriptionBuilder eventSubscription() {
+        return new EventSubscriptionBuilder();
+    }
+    
     public static ExternalComputeResourceBuilder externalComputeResource() {
         return new ExternalComputeResourceBuilder();
     }
@@ -426,6 +430,10 @@ public class Builders {
         return new LogicalUnitBuilder();
     }
     
+    public static MDevTypeBuilder mDevType() {
+        return new MDevTypeBuilder();
+    }
+    
     public static MacBuilder mac() {
         return new MacBuilder();
     }
