@@ -48,6 +48,22 @@ public class MemoryPolicyContainer extends Container implements MemoryPolicy {
         return guaranteed;
     }
     
+    public Byte guaranteedAsByte() {
+        return asByte("MemoryPolicy", "guaranteed", guaranteed);
+    }
+    
+    public Short guaranteedAsShort() {
+        return asShort("MemoryPolicy", "guaranteed", guaranteed);
+    }
+    
+    public Integer guaranteedAsInteger() {
+        return asInteger("MemoryPolicy", "guaranteed", guaranteed);
+    }
+    
+    public Long guaranteedAsLong() {
+        return asLong("MemoryPolicy", "guaranteed", guaranteed);
+    }
+    
     public void guaranteed(BigInteger newGuaranteed) {
         guaranteed = newGuaranteed;
     }
@@ -60,6 +76,22 @@ public class MemoryPolicyContainer extends Container implements MemoryPolicy {
         return max;
     }
     
+    public Byte maxAsByte() {
+        return asByte("MemoryPolicy", "max", max);
+    }
+    
+    public Short maxAsShort() {
+        return asShort("MemoryPolicy", "max", max);
+    }
+    
+    public Integer maxAsInteger() {
+        return asInteger("MemoryPolicy", "max", max);
+    }
+    
+    public Long maxAsLong() {
+        return asLong("MemoryPolicy", "max", max);
+    }
+    
     public void max(BigInteger newMax) {
         max = newMax;
     }
