@@ -242,6 +242,17 @@ public interface VmsService extends Service {
          * ----
          */
         AddRequest clonePermissions(Boolean clonePermissions);
+        /**
+         * Relevant for admin users only. Indicates whether to assign UserVmManager role
+         * on the created Virtual Machine for this user. This will enable the user to later access
+         * the Virtual Machine as though he were a non-admin user, foregoing his admin permissions
+         * (by providing filter=true).
+         * 
+         * NOTE: admin-as-user (meaning providing filter=true) POST requests on an existing Virtual
+         * Machine will fail unless the Virtual Machine has been previously created by the admin as
+         * a user (meaning with filter=true).
+         */
+        AddRequest filter(Boolean filter);
         AddRequest vm(Vm vm);
         AddRequest vm(VmBuilder vm);
     }
@@ -627,6 +638,17 @@ public interface VmsService extends Service {
          * ----
          */
         AddFromConfigurationRequest clonePermissions(Boolean clonePermissions);
+        /**
+         * Relevant for admin users only. Indicates whether to assign UserVmManager role
+         * on the created Virtual Machine for this user. This will enable the user to later access
+         * the Virtual Machine as though he were a non-admin user, foregoing his admin permissions
+         * (by providing filter=true).
+         * 
+         * NOTE: admin-as-user (meaning providing filter=true) POST requests on an existing Virtual
+         * Machine will fail unless the Virtual Machine has been previously created by the admin as
+         * a user (meaning with filter=true).
+         */
+        AddFromConfigurationRequest filter(Boolean filter);
         AddFromConfigurationRequest vm(Vm vm);
         AddFromConfigurationRequest vm(VmBuilder vm);
     }
@@ -708,6 +730,17 @@ public interface VmsService extends Service {
          * ----
          */
         AddFromScratchRequest clonePermissions(Boolean clonePermissions);
+        /**
+         * Relevant for admin users only. Indicates whether to assign UserVmManager role
+         * on the created Virtual Machine for this user. This will enable the user to later access
+         * the Virtual Machine as though he were a non-admin user, foregoing his admin permissions
+         * (by providing filter=true).
+         * 
+         * NOTE: admin-as-user (meaning providing filter=true) POST requests on an existing Virtual
+         * Machine will fail unless the Virtual Machine has been previously created by the admin as
+         * a user (meaning with filter=true).
+         */
+        AddFromScratchRequest filter(Boolean filter);
         AddFromScratchRequest vm(Vm vm);
         AddFromScratchRequest vm(VmBuilder vm);
     }
@@ -789,6 +822,17 @@ public interface VmsService extends Service {
          * ----
          */
         AddFromSnapshotRequest clonePermissions(Boolean clonePermissions);
+        /**
+         * Relevant for admin users only. Indicates whether to assign UserVmManager role
+         * on the created Virtual Machine for this user. This will enable the user to later access
+         * the Virtual Machine as though he were a non-admin user, foregoing his admin permissions
+         * (by providing filter=true).
+         * 
+         * NOTE: admin-as-user (meaning providing filter=true) POST requests on an existing Virtual
+         * Machine will fail unless the Virtual Machine has been previously created by the admin as
+         * a user (meaning with filter=true).
+         */
+        AddFromSnapshotRequest filter(Boolean filter);
         AddFromSnapshotRequest vm(Vm vm);
         AddFromSnapshotRequest vm(VmBuilder vm);
     }
