@@ -15,30 +15,40 @@ limitations under the License.
 
 package org.ovirt.engine.sdk4.types;
 
-
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 public enum GlusterState {
+    DOWN("down"),
+    UNKNOWN("unknown"),
+    UP("up"),
+    ;
     
-    UP,
-    DOWN,
-    UNKNOWN;
+    private static final Logger log = LoggerFactory.getLogger(GlusterState.class);
     
-    private static final Logger LOG = LoggerFactory.getLogger(GlusterState.class);
+    private String image;
+    
+    GlusterState(String image) {
+        this.image = image;
+    }
     
     public String value() {
-        return name().toLowerCase();
+        return image;
     }
     
     public static GlusterState fromValue(String value) {
         try {
             return valueOf(value.toUpperCase());
         }
-        catch (IllegalArgumentException e) {
-            LOG.error("The string '" + value + "' isn't a valid value for the 'GlusterState' enumerated type. Valid values are: 'up', 'down', 'unknown'.");
+        catch (IllegalArgumentException exception) {
+            log.error(
+            "The string '" + value + "' isn't a valid value for the 'GlusterState' enumerated type. " +
+            "Valid values are 'down', 'unknown' and 'up'.",
+            exception
+            );
             return null;
         }
     }
     
 }
+
